## 1
What is the output of the following Python code? `x = [1, 2, 3]; y = x; y.append(4); print(x)`
 * `[1, 2, 3, 4]`
 * `[1, 2, 3]`
 * `[1, 2, 3, [4]]`
 * A `SyntaxError` is raised.

## 2
What is the value of the following integral? $\int_0^\infty e^{-x^2} dx$
 * $\frac{\sqrt{\pi}}{2}$
 * $\sqrt{\pi}$
 * $\frac{\pi}{2}$
 * $\pi$

## 3
> ![Image](test_image.jpg)
What animal is shown in the image?
 * A bird
 * A dog
 * A cat
 * A fish

## 4
Which of the following is NOT a primary color?
 * Green
 * Red
 * Blue
 * Yellow

